@@ -10,17 +10,21 @@ test_that("inputs to sumFig are as expected", {
   x <- myOccCiteObject@occResults[[1]]
   tabResults <- tabulate.occResults(x = x, sp.name = sp.name)
 
-  expect_true(class(myOccCiteObject)=="occCiteData")
-  expect_true(names(myOccCiteObject@occResults)>0)
+  expect_true(class(myOccCiteObject) == "occCiteData")
+  expect_true(names(myOccCiteObject@occResults) > 0)
   expect_true(is.character(resNames))
-  expect_true(all(!is.na(stringr::str_extract(string = resNames,
-                                              pattern = "(\\w+\\s\\w+)"))))
+  expect_true(all(!is.na(stringr::str_extract(
+    string = resNames,
+    pattern = "(\\w+\\s\\w+)"
+  ))))
 
-  expect_true(all(c("name",
-                    "year",
-                    "DataService",
-                    "Dataset")
-                  %in% names(tabulate.occResults(x, sp.name))))
+  expect_true(all(c(
+    "name",
+    "year",
+    "DataService",
+    "Dataset"
+  )
+  %in% names(tabulate.occResults(x, sp.name))))
 })
 
 test_that("default sumFig settings work", {
@@ -37,7 +41,7 @@ test_that("default sumFig settings work", {
 test_that("sumFig works when plotting by species", {
   data("myOccCiteObject")
   test <- plot(myOccCiteObject, bySpecies = T)
-  expect_true(names(test)=="Protea cynaroides")
+  expect_true(names(test) == "Protea cynaroides")
   expect_true("yearHistogram" %in% names(test[[1]]))
   expect_equal(class(test[[1]][[1]]), "ggplot_built")
   expect_true("source" %in% names(test[[1]]))
@@ -49,7 +53,7 @@ test_that("sumFig works when plotting by species", {
 test_that("sumFig works when plotting only year histogram by species", {
   data("myOccCiteObject")
   test <- plot(myOccCiteObject, bySpecies = T, plotTypes = "yearHistogram")
-  expect_true(names(test)=="Protea cynaroides")
+  expect_true(names(test) == "Protea cynaroides")
   expect_true("yearHistogram" %in% names(test[[1]]))
   expect_equal(class(test[[1]][[1]]), "ggplot_built")
 })
@@ -57,7 +61,7 @@ test_that("sumFig works when plotting only year histogram by species", {
 test_that("sumFig works when plotting only source by species", {
   data("myOccCiteObject")
   test <- plot(myOccCiteObject, bySpecies = T, plotTypes = "source")
-  expect_true(names(test)=="Protea cynaroides")
+  expect_true(names(test) == "Protea cynaroides")
   expect_true("source" %in% names(test[[1]]))
   expect_equal(class(test[[1]][[1]]), "ggplot_built")
 })
@@ -65,7 +69,7 @@ test_that("sumFig works when plotting only source by species", {
 test_that("sumFig works when plotting only aggregator by species", {
   data("myOccCiteObject")
   test <- plot(x = myOccCiteObject, bySpecies = T, plotTypes = "aggregator")
-  expect_true(names(test)=="Protea cynaroides")
+  expect_true(names(test) == "Protea cynaroides")
   expect_true("aggregator" %in% names(test[[1]]))
   expect_equal(class(test[[1]][[1]]), "ggplot_built")
 })
